# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import event_mail
from . import event_mail_registration
from . import sms_template
